@@ -2,7 +2,9 @@ import os
 
 SPOJ_URL = 'http://www.spoj.com/'
 LOGIN_URL = SPOJ_URL
-MN_SPOJ_URL = '%sABRAMOV/' % SPOJ_URL
+spoj_dirname = 'ABRAMOV'
+
+ROOM_URL = lambda : SPOJ_URL + spoj_dirname +'/'
 
 CONFIG_FILE_NAME = os.path.expanduser('~/.spojrc')
 COOKIE_FILE_NAME = os.path.expanduser('~/.spoj_cookie')
@@ -11,5 +13,4 @@ user_name = None
 #cookie jar
 cj = None
 
-def _url(path):
-    return MN_SPOJ_URL + path + '/'
+_url = lambda path: ROOM_URL() + path + '/'
